@@ -1,6 +1,6 @@
 package Mail::BIMI::VMC;
 # ABSTRACT: Class to model a VMC
-our $VERSION = '2.20201013.1'; # VERSION
+our $VERSION = '2.20201013.2'; # VERSION
 use 5.20.0;
 use Moose;
 use Mail::BIMI::Prelude;
@@ -198,7 +198,7 @@ sub _build_indicator($self) {
   if ( $uri =~ /^data:image\/svg\+xml;base64,/ ) {
     my ( $null, $base64 ) = split( ',', $uri );
     my $data = MIME::Base64::decode($base64);
-    return Mail::BIMI::Indicator->new( location => $self->indicator_uri, data => $data, bimi_object => $self->bimi_object, source => 'VMC' );
+    return Mail::BIMI::Indicator->new( uri => $self->uri, data => $data, bimi_object => $self->bimi_object, source => 'VMC' );
   }
   else {
     $self->add_error('VMC_PARSE_ERROR','Could not extract SVG from VMC');
@@ -276,7 +276,7 @@ Mail::BIMI::VMC - Class to model a VMC
 
 =head1 VERSION
 
-version 2.20201013.1
+version 2.20201013.2
 
 =head1 DESCRIPTION
 
